/**
 * TCS Dependency Map Renderer
 *
 * Copyright (c) 2005 TopCoder, Inc. All rights Reserved.
 */
package com.topcoder.rules.dependencymap.view.failuretests;

import java.awt.Insets;
import java.awt.image.BufferedImage;
import java.io.File;

import junit.framework.TestCase;

import com.topcoder.rules.dependencymap.view.BufferedImageRenderer;
import com.topcoder.rules.dependencymap.view.Dependency;
import com.topcoder.rules.dependencymap.view.Graphics2DAdapter;
import com.topcoder.rules.dependencymap.view.SVGRenderer;
import com.topcoder.rules.dependencymap.view.ShapeFactory;

/**
 * Failure test cases for new Graphics2DAdapter and related new rendering path.
 *
 * @author AdamSelene
 */
public class G2DTest extends TestCase {
    
	private Insets goodInset = new Insets(1,2,3,4);
	private Dependency goodDep = new Dependency("test");
	private SVGRenderer svgr = new SVGRenderer(new File("test_files/failuretests/failure_blank.svg"));
	//private SVGRender goodGraphics = svgr.getGraphics(goodDep, 1000, 1000);
	private ShapeFactory goodSF = new ShapeFactory();

    /**
     * Tests null handling in G2D constructor.
     */
	public void testNull()
	{
		try {
			new Graphics2DAdapter(null);
			fail ("No ex");
		} catch (NullPointerException npe) { /* expected */ }
	}
	
    /**
     * Illegal type to BufferedImageRenderer
     */
    public void testIAE()
	{
		try {
			new BufferedImageRenderer(1,1, -1);			fail ("No ex");
		} catch (IllegalArgumentException npe) { /* expected */ }
	}

    /**
     * Illegal dimension (1) via constructor.
     */
	public void testIAE2()
	{
		try {
			new BufferedImageRenderer(-1,1, BufferedImage.TYPE_3BYTE_BGR);
			fail ("No ex");
		} catch (IllegalArgumentException npe) { /* expected */ }
	}
	
    /**
     * Illegal dimension (2) via constructor.
     */
    public void testIAE3()
	{
		try {
			new BufferedImageRenderer(1,-1, BufferedImage.TYPE_3BYTE_BGR);
			fail ("No ex");
		} catch (IllegalArgumentException npe) { /* expected */ }
	}
	
    /**
     * Illegal dimension to setHeight.
     */
	public void testIAE4()
	{
		try {
			new BufferedImageRenderer(1,1, BufferedImage.TYPE_3BYTE_BGR).setHeight(-1);
			fail ("No ex");
		} catch (IllegalArgumentException npe) { /* expected */ }
	}
	
    /**
     * Invalid image type to setImageType.
     */
	public void testIAE5()
	{
		try {
			new BufferedImageRenderer(1,1, BufferedImage.TYPE_3BYTE_BGR).setImageType(-1);
			fail ("No ex");
		} catch (IllegalArgumentException npe) { /* expected */ }
	}
	
    /**
     * Invalid dimension to setWidth.
     */
	public void testIAE6()
	{
		try {
			new BufferedImageRenderer(1,1, BufferedImage.TYPE_3BYTE_BGR).setWidth(-1);
			fail ("No ex");
		} catch (IllegalArgumentException npe) { /* expected */ }
	}
}